Counter

Struct Counter 

pub struct Counter(pub AtomicU64);
A thin wrapper around AtomicU64 that implements CloseValue.

This is provided for convenience to avoid the need to specify an ordering. However, all other atomics also implement CloseValue and can be used directly.

Tuple Fields

0: AtomicU64

Implementations

Source

impl Counter

pub const fn new(starting_count: u64) -> Self

Create a new Counter, initialized a specific value

pub fn increment(&self)

Add 1 to this counter

pub fn increment_scoped(&self) -> (CounterGuard<'_>, u64)

Increments the count by 1, returning a guard that decrements the count on drop, and the new value. Useful for tracking in-flight operations.

pub fn add(&self, i: u64)

Increase the value of this counter by i

pub fn set(&self, i: u64)

Set this counter to i, discarding the previous value

pub fn increment_owned(self: &Arc<Self>) -> (OwnedCounterGuard, u64)

Increments the count by 1, returning an owned guard that decrements the count on drop, and the new value.

Unlike increment_scoped, the returned OwnedCounterGuard can be moved across async boundaries or stored in structs without lifetime constraints.