pub trait CloseEntry: CloseValue<Closed: InflectableEntry> { }Expand description
An object that can be closed into an InflectableEntry. This is the
normal way of generating a metric entry - by starting with a a struct
that implements this trait (that is generally generated using the #[metrics] macro),
wrapping it in a RootEntry to generate an Entry, and then emitting that
to an EntrySink.
This is just a trait alias for CloseValue<Closed: InflectableEntry>.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".